@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration into rhythmic phrases
 
-our $VERSION = '0.0700';
+our $VERSION = '0.0701';
 
 use Moo;
 use strictures 2;
@@ -116,7 +116,7 @@ sub _build__pool_group {
 
 has remainder => (
     is      => 'ro',
-    default => sub { return 0 },
+    default => sub { return 1 },
 );
 
 
@@ -215,7 +215,7 @@ Music::Duration::Partition - Partition a musical duration into rhythmic phrases
 
 =head1 VERSION
 
-version 0.0700
+version 0.0701
 
 =head1 SYNOPSIS
 
@@ -341,7 +341,7 @@ entry should have a value greater than one.
 
 Append any remaining duration ticks to the end of the motif.
 
-Default: C<0>
+Default: C<1> Yes. Make it so.
 
 =head2 verbose
 
